#
# spec file for package python-evdev
#
# Copyright (c) 2020 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define modname evdev
%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-evdev
Version:        1.3.0
Release:        bp156.3.19
Summary:        Python bindings to the Linux input handling subsystem
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/gvalkov/python-evdev
# Source needs to be pulled form Github as the source distribution on PyPI lacks the test directory
Source:         https://github.com/gvalkov/python-evdev/archive/v%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
%python_subpackages

%description
python-evdev provides bindings to the generic input event interface
in Linux. The evdev interface serves the purpose of passing events
generated in the kernel directly to userspace through character
devices that are typically located in /dev/input/.

This package also comes with bindings to uinput, the userspace input
subsystem. Uinput allows userspace programs to create and handle
input devices that can inject events directly into the input
subsystem.

%prep
%setup -q

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}/%{$python_sitearch}

%check
%python_expand PYTHONPATH=%{buildroot}%{$python_sitearch} py.test-%{$python_version} tests -k 'not test_uinput'

%files %{python_files}
%{python_sitearch}/evdev*
%license LICENSE

%changelog
* Sun Jan 12 2020 Matthias Bach <marix@marix.org>
- Update to 1.3.0
  * Fix build on 32bit arches with 64bit time_t.
  * Add functionality to query device properties. See
    InputDevice.input_props and the input_props argument to Uinput.
  * KeyEvent received an allow_unknown constructor argument, which
    determines what will happen when an event code cannot be mapped
    to a keycode. The default and behavior so far has been to raise
    KeyError. If set to True, the keycode will be set to the event
    code formatted as a hex number.
  * Add InputDevice.set_absinfo() and InputDevice.absinfo().
  * Instruct the asyncio event loop to stop monitoring the fd of
    the input device when the device is closed.
* Tue May 14 2019 Ondřej Súkup <mimi.vx@gmail.com>
- update to 1.2.0
  * Add UInput support for the resolution parameter in AbsInfo
  * Vendor and product identifiers can be greater or equal to 0x8000
* Fri Mar  1 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.1.2:
  * Fix handling of absinfo capabilities
  * Fix invalid example
  * Check if FF_MAX_EFFECTS is defined
* Tue Aug 28 2018 marix@marix.org
- Update to version 1.1.0
  * Add support for handling force-feedback effect uploads.
  * Fix typo preventing force-feedback effects that need left
    coefficients from working.
- Add _service file to fetch source from Git.
* Tue Jun  5 2018 marix@marix.org
- Run tests during packaging.
  * This runs only those tests which do not require /dev/uinput.
- Changed to source taken directly from Git instead of PyPI.
* Mon Jun  4 2018 marix@marix.org
- Update to version 1.0.0
  * Fixed asyncio support in Python 3.5+.
  * Fixed handling of missing data.
  * Fixed device comparison.
  * Deprecated the InputDevice.fn attribute in favour of
    InputDevice.path
  * Add a context manager for grabbing access to a device -
    InputDevice.grab_context.
  * Add the InputDevice.uniq attribute, which contains the unique
    identifier of the device.
* Mon Jan 29 2018 jengelh@inai.de
- Initial package for openSUSE distro
